"""Version information for Financial Debt Optimizer."""

__version__ = "2.0.2"
__title__ = "Financial Debt Optimizer"
__description__ = (
    "A comprehensive tool for analyzing and optimizing debt repayment strategies"
)
__author__ = "Bryan Kemp"
__author_email__ = "bryan@kempville.com"
__license__ = "BSD-3-Clause"
__url__ = "https://github.com/bryankemp/financial-debt_optimizer"
